@@ -16,7 +16,7 @@ except: # pragma: no cover
 # Importing from green is done after coverage initialization
 
 
-def main():
+def main(testing=False):
     parser = argparse.ArgumentParser(
             add_help=False,
             description="Green is a clean, colorful test runner for Python unit tests.")
@@ -129,7 +129,12 @@ def main():
         tests = unittest.suite.TestSuite()
 
     # Actually run the tests
-    result = runner.run(tests)
+    if testing:
+        result = lambda: None
+        result.wasSuccessful = lambda: 0
+    else:
+        result = runner.run(tests)
+
     if args.run_coverage:
         stream.writeln()
         cov.stop()
@@ -148,3 +153,7 @@ def main():
         cov.report(file=stream, omit=omit)
     return(int(not result.wasSuccessful()))
 
+
+
+if __name__ == '__main__': # pragma: no cover
+    main()
